pub fn generate_fortress_pieces(
chunk_x: i32,
chunk_z: i32,
rng: &mut LegacyRandom,
) -> Vec<FortressPiece>Expand description
All fortress pieces for the chunk, vertically offset into Y ∈ [48, 70].
pub fn generate_fortress_pieces(
chunk_x: i32,
chunk_z: i32,
rng: &mut LegacyRandom,
) -> Vec<FortressPiece>All fortress pieces for the chunk, vertically offset into Y ∈ [48, 70].